@@ -188,6 +188,20 @@ class TestImportStatement(unittest.TestCase):
                                                  ImportStatement.__name__)
         )
 
+    def test_add(self):
+        with self.assertRaises(AssertionError):
+            ImportStatement([], 'a') + ImportStatement([], 'b')
+
+        actual = (ImportStatement([1, 2], 'a', [ImportLeaf('b')])
+                  + ImportStatement([3, 4], 'a', [ImportLeaf('c')]))
+
+        self.assertEqual(
+            actual,
+            ImportStatement([1, 2, 3, 4], 'a', [ImportLeaf('b'),
+                                                ImportLeaf('c')])
+        )
+        self.assertListEqual(actual.line_numbers, [1, 2, 3, 4])
+
     def test_eq(self):
         self.assertTrue(
             ImportStatement([], 'a', [ImportLeaf('a')])
